function [N,E,Z]=coord2grid_ARMY(latd,longd,a,b,f)

%Last-Updated: 19.04.2014
%Formulae: ARMY - DMA TM 8358.2
%Notes:	Unless otherwise specified, assume that;
%		all lengths are in metres, all geographic
%		coordinates are in radians, and the sign
%		notation is negative for the southern and
%		western hemisphere.

%Calculate UTM Zone number
Z = 1+floor((longd+180)/6);

%Calculate central meridian of zone
Zcm = 3+6*(Z-1)-180;

%Setting coordinates to radians
lat = (latd/360)*2*pi;
long = (longd/360)*2*pi;

%First eccentricity squared
e2 = f*(2-f);

%Second eccentricity squared
ecc2 = (f*(2-f))/((1-f).^2);

n = f/(2-f);

%Radius of curvature in the meridian
rho = (a*(1-e2))/((1-e2*(sin(lat).^2)).^(3/2));

%Radius of curv. in the prime vertical
nu = rho*(1+ecc2*(cos(lat).^2));

%Meridional arc, S
AA = a*(1-n+(5/4)*(n.^2-n.^3)+(81/64)*(n.^4-n.^5));
BB = (3/2)*a*(n-n.^2+(7/8)*(n.^3-n.^4)+(55/64)*n.^5);
CC = (15/16)*a*(n.^2-n.^3+(3/4)*(n.^4-n.^5));
DD = (35/48)*a*(n.^3-n.^4+(11/16)*n.^5);
EE = (315/512)*a*(n.^4-n.^5);
S = AA*lat+BB*sin(2*lat)+CC*sin(4*lat)-DD*sin(6*lat)+EE*sin(8*lat);