function [N,E,Z,hemi]=coord2grid_USGS(latd,longd,a,b,f)

%Last-Updated: 01.05.2014
%Formulae: OGP 7-2, 1.3.5.1 USGS
%Notes: Modified TM for UTM
%		Hemi 1 means North, Hemi -1 means South

%Error codes for limits
if latd < -180 | latd > 180
	error('Latitude must be between 180 and -180.')
elseif longd < -90 | longd > 90
	error('Longitude must be between 90 and -90.')
elseif longd < -89 | longd > 89
	error('Longitude values close to 90 will not yield accurate results.')	
end
	
%Zone width, degrees
W = 6;

%False Easting, metre
FE = 500000;

%False Northing, metre
if latd >= 0;
	FN = 0;
	hemi = 1;
	else
	FN = 10000000;
	hemi = -1;
end

%Central Meridian scale factor
k0 = 0.9996;

%Calculate UTM Zone number
Z = 1+floor((longd+180)/W);

%Longitude of natural origin
longd0 = (3+W*(Z-1)-180);

%Latitude of natural origin
latd0 = 0;

%eccentricity
e = sqrt(2*f-f.^2);

%second eccentricity
ecc = sqrt(e.^2/(1-e.^2));

%Degrees to radians
lat = (latd/360)*2*pi;
lat0 = (latd0/360)*2*pi;
long = (longd/360)*2*pi;
long0 = (longd0/360)*2*pi;

T = (tan(lat).^2);
C = (e.^2*(cos(lat).^2))/(1-e.^2);
A = (long-long0)*cos(lat);
nu = a/(1-e.^2*(sin(lat).^2)).^0.5;

M = a*((1-(e.^2)/4-(3*e.^4)/64-(5*e.^6)/256)*lat ...
-((3*e.^2)/8+(3*e.^4)/32+(45*e.^6)/1024)*sin(2*lat) ...
+((15*e.^4)/256+(45*e.^6)/1024)*sin(4*lat) ...
-((35*e.^6)/3072)*sin(6*lat));

M0 = a*((1-(e.^2)/4-(3*e.^4)/64-(5*e.^6)/256)*lat0 ...
-((3*e.^2)/8+(3*e.^4)/32+(45*e.^6)/1024)*sin(2*lat0) ...
+((15*e.^4)/256+(45*e.^6)/1024)*sin(4*lat0) ...
-((35*e.^6)/3072)*sin(6*lat0));

E = FE+k0*nu*(A+(1-T+C)*((A.^3)/6)+(5-18*T+T.^2+72*C-58*ecc.^2)*((A.^5)/120));
N = FN+k0*(M-M0+nu*tan(lat)*((A.^2)/2+(5-T+9*C+4*C.^2)*((A.^4)/24)+(61-58*T+T.^2+600*C-330*ecc.^2)*((A.^6)/720)));

return


