function [latd,longd]=grid2coord_USGS(N,E,Z,a,b,f,hemi)

%Last-Updated: 01.05.2014
%Formulae: OGP 7-2, 1.3.5.1 USGS
%Notes: Modified TM for UTM
% 		uses the USGS formulae

%Error codes for limits
if E < 160000 | E > 840000
	error('Eastings may not exceed 840000 or be below 160000.')
elseif N < 0
	error('Negative Northing is not allow.')
elseif N > 10000000
	error('Northing may not exceed 10000000.')
end

%Central Meridian scale factor
k0 = 0.9996;

%eccentricity
e = sqrt(2*f-f.^2);

%Zone width, degrees
W = 6;

%False Northing
if hemi == 1
	FN = 0;
elseif hemi == -1
	FN = 10000000;
else
    error('Hemisphere must be 1 for North, or -1 for South.')
end

%second eccentricity
ecc = sqrt(e.^2/(1-e.^2));

%eccentricity squared
e2 = e.^2;

%second eccentricity squared
ecc2 = (e.^2/(1-e.^2));

%False Easting, metre
FE = 500000;

%Longitude of natural origin
longd0 = (3+6*(Z-1)-180);

%Latitude of natural origin
latd0 = 0;

%Degrees to radians
lat0 = (latd0/360)*2*pi;
long0 = (longd0/360)*2*pi;


M0 = a*((1-(e.^2)/4-(3*e.^4)/64-(5*e.^6)/256)*lat0 ...
-((3*e.^2)/8+(3*e.^4)/32+(45*e.^6)/1024)*sin(2*lat0) ...
+((15*e.^4)/256+(45*e.^6)/1024)*sin(4*lat0) ...
-((35*e.^6)/3072)*sin(6*lat0));

M1 = M0+(N-FN)/k0;
mu1 = M1/(a*(1-e2/4-e.^4*(3/64)-e.^6*(5/256)));
e1 = (1-(1-e2).^0.5)/(1+(1-e2).^0.5);

lat1 = mu1+(e1*(3/2)+e1.^3*(27/32))*sin(2*mu1) ...
+(e1.^2*(21/16)-e1.^4*(55/32))*sin(4*mu1) ...
+(e1.^3*(151/96))*sin(6*mu1) ...
+(e1.^4*(1097/512))*sin(8*mu1);

T1 = (tan(lat1).^2);
C1 = ecc2*(cos(lat1).^2);
nu1 = a/((1-e2*(sin(lat1).^2)).^0.5);
rho1 = (a*(1-e2))/((1-e2*(sin(lat1).^2)).^1.5);

D = (E-FE)/(nu1*k0);

lat = lat1-((nu1*tan(lat1))/rho1)*((D.^2)/2-(5+3*T1+10*C1-4*C1.^2-9*ecc2)*((D.^4)/24) ...
+(61+90*T1+298*C1+45*T1.^2-252*ecc2-3*C1.^2)*((D.^6)/720));
long = long0+(D-(1+2*T1+C1)*((D.^3)/6)+(5-2*C1+28*T1-3*C1.^2+8*ecc2+24*T1.^2)*((D.^5)/120))/cos(lat1);

latd = (lat/pi)*180;
longd = (long/pi)*180;
return