%Last-Updated: 19.05.2014
%Formulae: 
%Notes: A script made to check the difference between
%		the North Sea Formulae and Bursa-Wolf
%		when transforming from ED50 to WGS84
%		offshore Norway - produces a bar3 plot.

clear all

%Amount of steps
n = 40; 	%lat
d = n;		%long

%Start - UK/Norway boundary (roughly)
startlong = 1.1; %degrees East

%Stop - Mainland Norway (roughly)
stoplong = 4.9; %degrees East

startlat = 52;
stoplat = 68;
 
%Length of step
dd = (stoplat-startlat)/d;
dn = (stoplong-startlong)/n;

%Setting lat and long values for each step
long = zeros(n:1);
lat = zeros(n:1);
H = zeros(n:1);

long(1) = startlong;
lat(1) = startlat;

for i=2:n;
	long(i) = long(i-1)+dn;
end

for r=2:d;
	lat(r) = lat(r-1)+dd;
end

%Get ellipsoid parameters for ED50
[a_ED50,b_ED50,f_ED50]=ellipsoid(17);

%Get ellipsoid parameters for WGS84 (23)
[a_WGS84,b_WGS84,f_WGS84]=ellipsoid(23);

%Parameters for ED87 to WGS84SEA
tX = -82.981;
tY = -99.719;
tZ = -110.709;
rX = -0.5076E-6;
rY = +0.1503E-6;
rZ = +0.3898E-6;
D = -0.3143;

%Parameters for ED50 to WGS84 North of 62deg
tX2 =-116.641;
tY2 = -56.931;
tZ2 = -110.559;
rX2 = +4.327*10.^-6;
rY2 = +4.464*10.^-6;
rZ2 = -4.444*10.^-6;
dS2 = -3.520;


for r = 1:d; 

	for i = 1:n;
	
	%Assume MSL = 0, H = 0
	H(i) = 0;

	%Start North Sea Formulae
	%Step 1: Calculate change in lat/long to ED87
	[D_lat(r,i),D_long(r,i)]=northsea1(lat(r),long(i),1);
	
	%Add changes to initial values
	lat_ED87(r,i)=D_lat(r,i)+lat(r);
	long_ED87(r,i)=D_long(r,i)+long(i);
	
	%Convert to Cartesian with ED50 ellipsoid (same as ED87)
	[X_ED87(r,i),Y_ED87(r,i),Z_ED87(r,i)]=geo2cart(lat_ED87(r,i),long_ED87(r,i),H(i),a_ED50,b_ED50);
	
	%Step 2: Transform ED87 to WGS84SEA
	[X_WGS84SEA(r,i),Y_WGS84SEA(r,i),Z_WGS84SEA(r,i)]=helmert7(X_ED87(r,i),Y_ED87(r,i),Z_ED87(r,i),tX(1),tY(1),tZ(1),rX(1),rY(1),rZ(1),D(1));
	
	%Convert back to Geographic with WGS84 ellipsoid
	[lat_WGS84SEA(r,i),long_WGS84SEA(r,i),H_WGS84SEA(r,i)]=cart2geo(X_WGS84SEA(r,i),Y_WGS84SEA(r,i),Z_WGS84SEA(r,i),a_WGS84,b_WGS84);
	%End of North Sea Formulae
	
	%Start Helmert 7-parameter
	%Convert to Cartesian with ED50 ellipsoid
	[X_ED50(r,i),Y_ED50(r,i),Z_ED50(r,i)]=geo2cart(lat(r),long(i),H(i),a_ED50,b_ED50);
	
	%Use Helmert 7 North of 62°N
	[X_WGS84(r,i),Y_WGS84(r,i),Z_WGS84(r,i)]=helmert7(X_ED50(r,i),Y_ED50(r,i),Z_ED50(r,i),tX2(1),tY2(1),tZ2(1),rX2(1),rY2(1),rZ2(1),dS2(1));
	
	%Convert back to Geographic with WGS84 ellipsoid
	[lat_WGS84(r,i),long_WGS84(r,i),H_WGS84(r,i)]=cart2geo(X_WGS84(r,i),Y_WGS84(r,i),Z_WGS84(r,i),a_WGS84,b_WGS84);
	%End Helmert 7-parameter
	
	%Calculate the difference of each step in meters
	d_lat(r,i) = lat_WGS84(r,i) - lat_WGS84SEA(r,i);
	d_long(r,i) = long_WGS84(r,i) - long_WGS84SEA(r,i);
	d_H(r,i) = H_WGS84(r,i) - H_WGS84SEA(r,i);
	[deg_lat(r,i),min_lat(r,i),sec_lat(r,i)] = dec2coord(d_lat(r,i));
	[deg_long(r,i),min_long(r,i),sec_long(r,i)] = dec2coord(d_long(r,i));
	dist(r,i) = vdist(lat_WGS84(r,i),long_WGS84(r,i),lat_WGS84SEA(r,i),long_WGS84SEA(r,i));
	
	end
end

Y = long;
X = lat;
Z = dist;


Xtick(1) = startlong;
Ytick(1) = startlat;
for p = 2:11;
Xtick(p) = Xtick(p-1) + ((stoplong -  startlong)/11);
Ytick(p) = Ytick(p-1) + ((stoplat -  startlat)/11);
end

figure;
h = bar3(Z);
colorbar

set(gca,'XTick',[0:4:40])
set(gca,'YTick',[0:4:40])
set(gca,'XTickLabel',Xtick)
set(gca,'YTickLabel',Ytick)

title('Difference between North Sea Formulae and Bursa-Wolf');
xlabel('Degrees East');
ylabel('Degrees North');
zlabel('Meters');

for k = 1:length(h)
    zdata = get(h(k),'ZData');
    set(h(k),'CData',zdata,...
             'FaceColor','interp')
end