%Last-Updated: 11.04.2014
%Formulae: North Sea
%Notes: All values from Statens Kartverk
%		Script made to test functions/formulae 
%		vs. test values given by EPSG10 Annex 1
%		Tests tfm ED50 to WGS84SEA along 62 deg N

clear all

%Initial latitude values in ED50
lat_deg_ED50=[62 62 62 62 62 62 62 62 62 62 62 62];
lat_min_ED50=[0 0 0 0 0 0 0 0 0 0 0 0];
lat_sec_ED50=[0 0 0 0 0 0 0 0 0 0 0 0];

%Initial longitude values in ED50
long_deg_ED50=[1 1 2 2 2 3 3 3 4 4 4 4];
long_min_ED50=[22 40 0 20 40 0 20 40 0 20 40 52];
long_sec_ED50=[22.769 0 0 0 0 0 0 0 0 0 0 45.24];

%End latitude values in WGS84
lat_deg_WGS84SEA_SKV=[61 61 61 61 61 61 61 61 61 61 61 61 ];
lat_min_WGS84SEA_SKV=[59 59 59 59 59 59 59 59 59 59 59 59 ];
lat_sec_WGS84SEA_SKV=[58.273 58.29 58.309 58.328 58.346 58.363 58.378 58.393 58.407 58.429 58.444 58.454];

%End longitude values in WGS84
long_deg_WGS84SEA_SKV=[1 1 1 2 2 2 3 3 3 4 4 4];
long_min_WGS84SEA_SKV=[22 39 59 19 39 59 19 39 59 19 39 52];
long_sec_WGS84SEA_SKV=[16.261 53.513 53.539 53.568 53.599 53.631 53.665 53.697 53.728 53.69 53.731 39.004];


%Parameters for ED87 to WGS84SEA
tX=-82.981;
tY=-99.719;
tZ=-110.709;
rX=-0.5076E-6;
rY=+0.1503E-6;
rZ=+0.3898E-6;
D=-0.3143;

%Find the amount of elements
N=length(lat_deg_ED50);

%Assume MSL = 0, H = 0
H = 0;

%Get ellipsoid parameters for ED50
[a_ED50,b_ED50,f_ED50]=ellipsoid(17);

%Get ellipsoid parameters for WGS84 (23)
[a_WGS84,b_WGS84,f_WGS84]=ellipsoid(23);

%Run the transformation for every element
for i=1:N;
	
	%Convert to decimal
	[lat_ED50(i)]=coord2dec(lat_deg_ED50(i),lat_min_ED50(i),lat_sec_ED50(i));
	[long_ED50(i)]=coord2dec(long_deg_ED50(i),long_min_ED50(i),long_sec_ED50(i));
	
	%Step 1: Calculate change in lat/long to ED87
	[D_lat(i),D_long(i)]=northsea1(lat_ED50(i),long_ED50(i),1);
	
	%Add changes to initial values
	lat_ED87(i)=D_lat(i)+lat_ED50(i);
	long_ED87(i)=D_long(i)+long_ED50(i);
	
	%Convert to Cartesian with ED50 ellipsoid (same as ED87)
	[X_ED87(i),Y_ED87(i),Z_ED87(i)]=geo2cart(lat_ED87(i),long_ED87(i),H,a_ED50,b_ED50);
	
	%Step 2: Transform ED87 to WGS84SEA
	[X_WGS84SEA(i),Y_WGS84SEA(i),Z_WGS84SEA(i)]=helmert7(X_ED87(i),Y_ED87(i),Z_ED87(i),tX,tY,tZ,rX,rY,rZ,D);
	
	%Convert back to Geographic with WGS84 ellipsoid
	[lat_WGS84SEA(i),long_WGS84SEA(i),H_WGS84SEA(i)]=cart2geo(X_WGS84SEA(i),Y_WGS84SEA(i),Z_WGS84SEA(i),a_WGS84,b_WGS84);
		
end

%Calculate the error/off-set
for i=1:N;
	
	%Convert WGS84_SKV to decimal
	[lat_WGS84SEA_SKV(i)]=coord2dec(lat_deg_WGS84SEA_SKV(i),lat_min_WGS84SEA_SKV(i),lat_sec_WGS84SEA_SKV(i));
	[long_WGS84SEA_SKV(i)]=coord2dec(long_deg_WGS84SEA_SKV(i),long_min_WGS84SEA_SKV(i),long_sec_WGS84SEA_SKV(i));

	%Calculate offset
	offset_lat(i)=abs(lat_WGS84SEA_SKV(i))-abs(lat_WGS84SEA(i));
	offset_long(i)=abs(long_WGS84SEA_SKV(i))-abs(long_WGS84SEA(i));
	
	[off_deg_lat(i),off_min_lat(i),off_sec_lat(i)] = dec2coord(offset_lat(i));
	[off_deg_long(i),off_min_long(i),off_sec_long(i)] = dec2coord(offset_long(i));	
	
	dist(i) = vdist(abs(offset_lat(i)),abs(offset_long(i)),0,0);
	
end