%Last-Updated: 16.05.2014
%Formulae: Helmert-7
%Notes: All values from Statens Kartverk
% 		Purpose is to test the 7-parameter
%		function from ED87 to WGS84SEA

clear all

ED87_lat = [52 53 54 55 56 57 58 59 60 61 62];
ED87_long = [2 4 0 6 -2 8 8 4 2 0 2];

WGS84SEA_lat_deg = [51 52 53 54 55 56 57 58 59 60 61];
WGS84SEA_lat_min = [59 59 59 59 59 59 59 59 59 59 59];
WGS84SEA_lat_sec = [57.0927 57.2812 57.2224 57.5876 57.3584 57.9079 58.0334 57.9938 58.0339 58.0722 58.2998];

WGS84SEA_long_deg = [1 3 0 5 -2 7 7 3 1 0 1];
WGS84SEA_long_min = [59 59 0 59 0 59 59 59 59 0 59];
WGS84SEA_long_sec = [55.14 55.1916 -5.2508 55.1325 5.6811 55.0669 54.9297 54.3814 54.0159 -6.3666 53.6259];

%Find the amount of elements
N=length(ED87_long);

%Parameters for ED87 to WGS84SEA
tX=-82.981;
tY=-99.719;
tZ=-110.709;
rX=-0.5076E-6;
rY=+0.1503E-6;
rZ=+0.3898E-6;
D=-0.3143;

%Assume MSL = 0, H = 0
H = 0;

%Get ellipsoid parameters for ED87
[a_ED87,b_ED87,f_ED87]=ellipsoid(17);

%Get ellipsoid parameters for WGS84 (23)
[a_WGS84,b_WGS84,f_WGS84]=ellipsoid(23);

for i = 1:N;
	
	%Convert to Cartesian
	[X_ED87(i),Y_ED87(i),Z_ED87(i)]=geo2cart(ED87_lat(i),ED87_long(i),H,a_ED87,b_ED87);
	
	%Transform ED87 to WGS84SEA
	[X_WGS84SEA(i),Y_WGS84SEA(i),Z_WGS84SEA(i)]=helmert7(X_ED87(i),Y_ED87(i),Z_ED87(i),tX,tY,tZ,rX,rY,rZ,D);
	
	%Convert back to Geographic with WGS84 ellipsoid
	[WGS84SEA_lat2(i),WGS84SEA_long2(i),WGSSEA_H2(i)]=cart2geo(X_WGS84SEA(i),Y_WGS84SEA(i),Z_WGS84SEA(i),a_WGS84,b_WGS84);
	
	%Convert WGS84SEA solution to DD
	[WGS84SEA_lat(i)]=coord2dec(WGS84SEA_lat_deg(i),WGS84SEA_lat_min(i),WGS84SEA_lat_sec(i));
	[WGS84SEA_long(i)]=coord2dec(WGS84SEA_long_deg(i),WGS84SEA_long_min(i),WGS84SEA_long_sec(i));
	
	%Calculate difference
	off_lat(i) = abs(WGS84SEA_lat(i) - WGS84SEA_lat2(i));
	off_long(i) = abs(WGS84SEA_long(i) - WGS84SEA_long2(i));
	[off_lat_deg(i),off_lat_min(i),off_lat_sec(i)] = dec2coord(off_lat(i));
	[off_long_deg(i),off_long_min(i),off_long_sec(i)] = dec2coord(off_long(i));		
	dist(i) = vdist(off_lat(i),off_long(i),0,0);
	
end