%Last-Updated: 13.04.2014
%Formulae: North 
%Notes: All values from Statens Kartverk
%		Script made to test functions/formulae 
%		vs. test values given by EPSG10 Annex 1
%		Tests tfm ED50 to WGS84 along 62 deg N

clear all

%Initial latitude values in ED50
lat_deg_ED50=[62 62 62 62 62 62 62 62 62 62 62 62];
lat_min_ED50=[0 0 0 0 0 0 0 0 0 0 0 0];
lat_sec_ED50=[0 0 0 0 0 0 0 0 0 0 0 0];

%Initial longitude values in ED50
long_deg_ED50=[1 1 2 2 2 3 3 3 4 4 4 4];
long_min_ED50=[22 40 0 20 40 0 20 40 0 20 40 52];
long_sec_ED50=[22.769 0 0 0 0 0 0 0 0 0 0 45.24];

%End latitude values in WGS84
lat_deg_WGS84_SKV=[61 61 61 61 61 61 61 61 61 61 61 61 ];
lat_min_WGS84_SKV=[59 59 59 59 59 59 59 59 59 59 59 59 ];
lat_sec_WGS84_SKV=[58.343 58.355 58.369 58.383 58.397 58.411 58.425 58.439 58.453 58.466 58.48 58.488 ];

%End longitude values in WGS84
long_deg_WGS84_SKV=[1 1 1 2 2 2 3 3 3 4 4 4];
long_min_WGS84_SKV=[22 39 59 19 39 59 19 39 59 19 39 52 ];
long_sec_WGS84_SKV=[16.425 53.689 53.726 53.764 53.802 53.84 53.879 53.917 53.956 53.995 54.034 39.299 ];

%Parameters for ED50 to WGS84 North of 62deg
tX=-116.641;
tY=-56.931;
tZ=-110.559;
rX=+4.327*10.^-6;
rY=+4.464*10.^-6;
rZ=-4.444*10.^-6;
dS=-3.520;

%Find the amount of elements
N=length(lat_deg_ED50);

%Assume MSL = 0, H = 0
H = 0;

%Get ellipsoid parameters for ED50
[a_ED50,b_ED50,f_ED50]=ellipsoid(17);

%Get ellipsoid parameters for WGS84 (23)
[a_WGS84,b_WGS84,f_WGS84]=ellipsoid(23);

%Run the transformation for every element
for i=1:N;

	%Convert to decimal
	[lat_ED50(i)]=coord2dec(lat_deg_ED50(i),lat_min_ED50(i),lat_sec_ED50(i));
	[long_ED50(i)]=coord2dec(long_deg_ED50(i),long_min_ED50(i),long_sec_ED50(i));
	
	%Convert to Cartesian with ED50 ellipsoid
	[X_ED50(i),Y_ED50(i),Z_ED50(i)]=geo2cart(lat_ED50(i),long_ED50(i),H,a_ED50,b_ED50);
	
	%Use Helmert 7 North of 62°N
	[X_WGS84(i),Y_WGS84(i),Z_WGS84(i)]=helmert7(X_ED50(i),Y_ED50(i),Z_ED50(i),tX,tY,tZ,rX,rY,rZ,dS);
	
	%Convert back to Geographic with WGS84 ellipsoid
	[lat_WGS84(i),long_WGS84(i),H_WGS84(i)]=cart2geo(X_WGS84(i),Y_WGS84(i),Z_WGS84(i),a_WGS84,b_WGS84);
		
end

%Calculate the error/off-set
for i=1:N;
	
	%Convert WGS84_SKV to decimal
	[lat_WGS84_SKV(i)]=coord2dec(lat_deg_WGS84_SKV(i),lat_min_WGS84_SKV(i),lat_sec_WGS84_SKV(i));
	[long_WGS84_SKV(i)]=coord2dec(long_deg_WGS84_SKV(i),long_min_WGS84_SKV(i),long_sec_WGS84_SKV(i));

	%Calculate off-set
	offset_lat(i)=lat_WGS84(i)-lat_WGS84_SKV(i);
	offset_long(i)=long_WGS84(i)-long_WGS84_SKV(i);
	[off_deg_lat(i),off_min_lat(i),off_sec_lat(i)] = dec2coord(offset_lat(i));
	[off_deg_long(i),off_min_long(i),off_sec_long(i)] = dec2coord(offset_long(i));	
	
	dist(i) = vdist(abs(offset_lat(i)),abs(offset_long(i)),0,0);
end