% Worked Example

clear all

%Define coordinates
latD_rig = 61;
latM_rig = 59;
latS_rig = 30.45;
longD_rig = 2;
longM_rig = 30;
longS_rig = 20.10;
H_rig = 0;

latD_target = 62;
latM_target = 01;
latS_target = 04.30;
longD_target = 2;
longM_target = 30;
longS_target = 40;
H_target = -2300;

%Convert to DD
[latDD_rig] = coord2dec(latD_rig, latM_rig, latS_rig);
[longDD_rig] = coord2dec(longD_rig, longM_rig, longS_rig);

[latDD_target] = coord2dec(latD_target, latM_target, latS_target);
[longDD_target] = coord2dec(longD_target, longM_target, longS_target);

%Calculate geographic offset
[lat_off, long_off] = northsea1(latDD_rig, longDD_rig, 1);

%Transform to ED87
latDD_rig_ED87 = latDD_rig + lat_off;
longDD_rig_ED87 = longDD_rig + long_off;

%Get ellipsoid parameters
[a_ED87, b_ED87, f_ED87] = ellipsoid(17);
[a_WGS84, b_WGS84, f_WGS84] = ellipsoid(23);

%Convert to geocentrical coordinates
[X_rig_ED87, Y_rig_ED87, Z_rig_ED87] = geo2cart(latDD_rig_ED87, longDD_rig_ED87, H_rig, a_ED87, b_ED87);
[X_target, Y_target, Z_target_ED50] = geo2cart(latDD_target, longDD_target, H_target, a_ED87, b_ED87);

%Transform to WGS84
[X_rig_WGS84SEA, Y_rig_WGS84SEA, Z_rig_WGS84SEA] = helmert7(X_rig_ED87, Y_rig_ED87, Z_rig_ED87, -82.981, -99.719, -110.709, -0.5076E-6, 0.1503E-6, 0.3898E-6, -0.3143);
[X_target_WGS84, Y_target_WGS84, Z_target_WGS84] = helmert7(X_target, Y_target, Z_target_ED50, -116.641, -56.931, -110.559, 4.327E-6, 4.464E-6, -4.444E-6, -3.520);

%Convert to geographical coordinates
[latDD_rig_WGS84SEA, longDD_rig_WGS84SEA, H_rig_WGS84SEA] = cart2geo(X_rig_WGS84SEA, Y_rig_WGS84SEA, Z_rig_WGS84SEA, a_WGS84, b_WGS84);
[latDD_target_WGS84, longDD_target_WGS84, H_target_WGS84] = cart2geo(X_target_WGS84, Y_target_WGS84, Z_target_WGS84, a_WGS84, b_WGS84);

%Convert to UTM coordinates
[N_rig, E_rig, Z_rig, hemi_rig] = coord2grid_USGS(latDD_rig_WGS84SEA, longDD_rig_WGS84SEA, a_WGS84, b_WGS84, f_WGS84);
[N_target, E_target, Z_target, hemi_target] = coord2grid_USGS(latDD_target_WGS84, longDD_target_WGS84, a_WGS84, b_WGS84, f_WGS84);

%Calculate TVD (H + above MSL, water depth + below MSL)
TVD_wellhead = 180 - H_rig_WGS84SEA;
TVD_target = -H_target_WGS84;

%Calculate difference
DN = N_target - N_rig;
DE = E_target - E_rig;
DZ = Z_target - Z_rig;
DTVD = TVD_target - TVD_wellhead;
